#!/bin/bash
# 
# DISCLAIMER
#   Trigo Technologies, Inc. disclaims all warranties or representations herein,
#   whether express, implied or statutory, to the fullest extent
#   permissible by law, including the implied warranties of title,
#   fitness for a particular purpose and merchantability.
# 
# COPYRIGHTS
#   Copyright 2001, 2002 Trigo Technologies, Inc. All rights reserved.
# 
#   Trigo Technologies, Inc.
#   8000 Marina Blvd, Suite 810
#   Brisbane, CA 94005
#   U.S.A.
#   www.trigo.com
# 
# TRADEMARKS
#   Trigo, Trigo Enterprise, Trigo Content Suite, Trigo Commerce Suite,
#   and Trigo Platform are trademarks of Trigo Technologies, Inc.
#   All other company and product names are trademarks or registered
#   trademarks of their respective owners.
#


. ${TOP}/bin/get_params.sh

#----------------------------------------
#
# usage
#
#----------------------------------------

if [ "${_TRIGO_CODE}" = "" ]; then
    ${ECHO} "Usage: $0 --code=<companyCode> [--name=<companyName> --confirm_db=no --confirm_delete=no --qa_setup=no]"
    exit
fi

#----------------------------------------
# get company id
#----------------------------------------

CMP_CODE=${_TRIGO_CODE}
CMP_NAME=${_TRIGO_NAME}
QA_SETUP=${_TRIGO_QA_SETUP}
if [ -z "$CMP_NAME" ]; then
    export CMP_NAME=$CMP_CODE
fi

${ECHO}
${ECHO} company name: $CMP_NAME
${ECHO} company code: $CMP_CODE
. $DB_DIR/util/set_db.sh

${ECHO} ====================================================
${ECHO} Cleaning up data for $CMP_CODE
${ECHO} ====================================================

. ${DB_DIR}/util/cleanup_cmp.sh --confirm_db=no --code="$CMP_CODE" --db_output=no

# Get CMP_ID_PREFIX
. ${DB_DIR}/cmp/get_cmpid_prefix.sh --confirm_db=no


#----------------------------------------
# init vars
#----------------------------------------

CMP_DIR=$DB_DIR/cmp

DML_SQL_SRC_FILE=${CMP_DIR}/dml_create_cmp.sql
DML_SQL_FILE=${CMP_DIR}/tmpcreatecmp.sql

CMP_PREFIX=$CMP_ID_PREFIX
CMP_COMPANY_ID="${CMP_PREFIX}0001"

BASIC_SCRIPT_SRC_FILE=${CMP_DIR}/basic_company_setup.script
BASIC_SCRIPT_FILE=${CMP_DIR}/basic_company_setup.script.tmp

# Get Sequence Values
. ${CMP_DIR}/set_create_cmp.sh --confirm_db=no


${ECHO} ====================================================
${ECHO} Creating sql script for $CMP_CODE
${ECHO} ====================================================

cd $CMP_DIR
${CAT} ${DML_SQL_SRC_FILE} \
    | ${SED} "s/%CMP_CODE%/$CMP_CODE/g" \
    | ${SED} "s/%CMP_NAME%/$CMP_NAME/g" \
    | ${SED} "s/%CMP_COMPANY_ID%/$CMP_COMPANY_ID/g" \
    | ${SED} "s/%CMP_PREFIX%/$CMP_PREFIX/g" \
    > ${DML_SQL_FILE}

${CAT} ${BASIC_SCRIPT_SRC_FILE} \
    | ${SED} "s/%CMP_CODE%/$CMP_CODE/g" \
    | ${SED} "s/%CMP_NAME%/$CMP_NAME/g" \
    > ${BASIC_SCRIPT_FILE}

${ECHO}
${ECHO} ====================================================
${ECHO} Populating starter data for $CMP_CODE
${ECHO} ====================================================
${ECHO}

cd $CMP_DIR

. ${DB_DIR}/util/run_db_cmd.sh --file=${DML_SQL_FILE}

${ECHO}
${ECHO} ====================================================
${ECHO} Building basic objects, users, roles for $CMP_CODE
${ECHO} ====================================================
${ECHO}
${JAVA_RT} austin.interpreter.test.TestScript --companycode="$CMP_CODE" \
                                              --username="trigo_root" \
                                              --scriptpath="${BASIC_SCRIPT_FILE}"
${ECHO}
${ECHO} ====================================================
${ECHO} Loading scripts for $CMP_CODE
${ECHO} ====================================================
${ECHO}
$JAVA_RT_NOOUT trigo_docstore.util.DocLoader "$CMP_CODE" Admin ${SCRIPTS_DIR}/common/common_scripts.xml Cp1252

${RM} ${DML_SQL_FILE}
${RM} ${BASIC_SCRIPT_FILE}

