#!/bin/bash
# 
# DISCLAIMER
#   Trigo Technologies, Inc. disclaims all warranties or representations herein,
#   whether express, implied or statutory, to the fullest extent
#   permissible by law, including the implied warranties of title,
#   fitness for a particular purpose and merchantability.
# 
# COPYRIGHTS
#   Copyright 2001, 2002 Trigo Technologies, Inc. All rights reserved.
# 
#   Trigo Technologies, Inc.
#   8000 Marina Blvd, Suite 810
#   Brisbane, CA 94005
#   U.S.A.
#   www.trigo.com
# 
# TRADEMARKS
#   Trigo, Trigo Enterprise, Trigo Content Suite, Trigo Commerce Suite,
#   and Trigo Platform are trademarks of Trigo Technologies, Inc.
#   All other company and product names are trademarks or registered
#   trademarks of their respective owners.
#


${ECHO}
${ECHO} "********************************************************"
${ECHO} "********************************************************"
${ECHO} "**"
${ECHO} "** You are about to run create_schema"
${ECHO} "** The database will be wiped out"
${ECHO} "**"
${ECHO} "********************************************************"
${ECHO} "********************************************************"
${ECHO}

. ${TOP}/src/db/schema/util/set_db.sh

${ECHO}
${ECHO} "********************************************************"
${ECHO} "********************************************************"
${ECHO} "**"
${ECHO} "** Please confirm one more time"
${ECHO} "**"
${ECHO} "********************************************************"
${ECHO} "********************************************************"
${ECHO}

. ${TOP}/src/db/schema/util/set_db.sh


. ${TOP}/src/db/schema/util/drop_temp_agg_tables.sh --confirm_db=no
. ${TOP}/src/db/schema/util/drop_log_tables_seq.sh --confirm_db=no
${ECHO}
${ECHO} ====================================================
${ECHO} Creating Application Tables
${ECHO} ====================================================
${ECHO}

cd $DB_ROOT_DIR/schema

#                     declared in pa.rc

for DDL in `ls gen/ddl_*.sql 2>/dev/null`
do
  ${ECHO}
  ${ECHO} ====================================================
  ${ECHO} "Running SQL File for Table/Synonym creation :"
  ${ECHO} $DDL
  ${ECHO} ====================================================
  ${ECHO}
  . ${DB_DIR}/util/run_db_cmd.sh --file=$DDL --errorfilter=yes
done


if [ "$AUSTIN_MODE" = "dev" -o "$AUSTIN_MODE" = "qa" ]; then
${ECHO}
${ECHO} ====================================================
${ECHO} Building dev/qa Constraints
${ECHO} ====================================================
${ECHO}

. ${DB_DIR}/util/run_db_cmd.sh --file=${DB_DIR}/sanitychecks/create_devonly_constraints.sql --errorfilter=yes

fi


${ECHO}
${ECHO} ====================================================
${ECHO} Creating PLAN Tables
${ECHO} ====================================================
${ECHO}
. ${DB_DIR}/util/run_db_cmd.sh --file=$DB_SCRIPTS/ddl_performance.sql --errorfilter=yes


${ECHO}
${ECHO} ====================================================
${ECHO} Creating Database Objects
${ECHO} ====================================================
${ECHO}

. ${TOP}/src/db/schema/util/create_db_functions.sh

${ECHO}
${ECHO} ====================================================
${ECHO} Loading Stored Procedures
${ECHO} ====================================================
${ECHO}

for FILE in `ls $TOP/src/db/schema/gen/proc*.sql 2>/dev/null`
do

. ${DB_DIR}/util/run_db_cmd.sh --file=$FILE --disconnect=yes --errorfilter=yes

done

${ECHO}
${ECHO} ====================================================
${ECHO} Populating Starter Data
${ECHO} ====================================================
${ECHO}

. ${DB_DIR}/util/run_db_cmd.sh --file=$DB_SCRIPTS/dml_pgc_page_customization.sql --errorfilter=yes
. ${DB_DIR}/util/run_db_cmd.sh --file=$DB_SCRIPTS/dml_per_personalization.sql --errorfilter=yes

${ECHO}
${ECHO} ====================================================
${ECHO} Building Indexes
${ECHO} ====================================================
${ECHO}
#
# Re-create the indexes.
# We want to create the indexes after populating the database to make
# the inserts faster.
# Note: Dropping a table automatically drops any indexes associated with the table.
#
for FILE in `ls $TOP/src/db/schema/gen/idx*.sql 2>/dev/null`
do
${ECHO}
${ECHO} ====================================================
${ECHO} "Running SQL File for Index creation :"
${ECHO} " $FILE"
${ECHO} ====================================================
${ECHO}

. ${DB_DIR}/util/run_db_cmd.sh --file=$FILE --errorfilter=yes

done


cd $TOP
${MKDIR} logs
cd logs
${TOUCH} system_default.log

cd ${TOP}/src/db/schema/create

# ${ECHO} ====================================================
# ${ECHO} stored procedures
# ${ECHO} ====================================================

# for FILE in `ls $TOP/src/db/schema/proc/*.sql 2>/dev/null`
# do
# echo "file is $FILE"
# ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF
# start $FILE
# EOF
# done

${ECHO}
${ECHO} ====================================================
${ECHO} Privileges
${ECHO} ====================================================
${ECHO}
${JAVA_RT_NOOUT} austin.generate.GenObjectTypeInfoToDb

${ECHO}
${ECHO} ====================================================
${ECHO} Creating Trigo and Mktplaces
${ECHO} ====================================================
${ECHO}

${TOP}/src/db/schema/trigo/create_trigo.sh --confirm_db=no
${TOP}/src/db/schema/mktplaces/create_mktplaces.sh --confirm_db=no

#${ECHO} ====================================================
#${ECHO} Creating supplier companies
#${ECHO} ====================================================

#${TOP}/src/db/schema/cmp/create_cmp.sh --code=yahoo

#cd ${TOP}/src/db/schema/create/

${ECHO} ====================================================
${ECHO} Analyzing
${ECHO} ====================================================
cd ${TOP}/src/db/schema/util
#./analyze_schema.sh --confirm_db=no


${ECHO} ====================================================
${ECHO} DONE
${ECHO} ====================================================
