#!/bin/bash
# 
# DISCLAIMER
#   Trigo Technologies, Inc. disclaims all warranties or representations herein,
#   whether express, implied or statutory, to the fullest extent
#   permissible by law, including the implied warranties of title,
#   fitness for a particular purpose and merchantability.
# 
# COPYRIGHTS
#   Copyright 2001, 2002 Trigo Technologies, Inc. All rights reserved.
# 
#   Trigo Technologies, Inc.
#   8000 Marina Blvd, Suite 810
#   Brisbane, CA 94005
#   U.S.A.
#   www.trigo.com
# 
# TRADEMARKS
#   Trigo, Trigo Enterprise, Trigo Content Suite, Trigo Commerce Suite,
#   and Trigo Platform are trademarks of Trigo Technologies, Inc.
#   All other company and product names are trademarks or registered
#   trademarks of their respective owners.
#


# 
# sanitycheck/cleanup_new.sh
#  
# This file reports on existing bad data in db into STDOUT
# This file reports its progress into STDERR 
#  


# get src connection descriptor
. ${TOP}/src/db/schema/util/set_db.sh
. ${TOP}/bin/read_config_file.sh $TOP/etc/austin.properties
$MKDIR ${_TRIGO_CONF_TMP_DIR}
tmpfile=${_TRIGO_CONF_TMP_DIR}sanitycheck.cleanup.sh.out

TOP_SQL="
set sqlnumber off;
set heading off;
set pagesize 0;
set linesize 10000;
set echo off;
set show off;
set feedback on;
set trimspool on;
set term off;
"

#CheckItaValueNumeric
#
# ita_value_numeric should never have Integer.MIN_VALUE Or Long.MIN_VALUE as values;
# some code critical code depends on this being true.
#
CheckItaValueNumeric() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile
    update tctg_ita_item_attributes
    set ita_value_numeric = null
    where ita_value_numeric = -9223372036854775808 or ita_value_numeric =  -2147483648;
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows updated." ]; then
        ${ECHO} "Fixed [$cnt] invalid ita_value_numeric entries!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for bad ita_value_numeric data" 1>/dev/null 1>&2
}



#CheckDupChi
#
# some bugs with duplicate chi rows
#
CheckDupChi() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from tctg_chi_category_hierarchy chi1
    where chi1.chi_next_version_id = 999999999
      and (exists (select 1 from tctg_chi_category_hierarchy chi2
                   where chi1.chi_company_id = chi2.chi_company_id
                     and chi1.chi_parent_id = chi2.chi_parent_id
                     and chi1.chi_child_id = chi2.chi_child_id
                     and chi1.chi_next_version_id = chi2.chi_next_version_id
                     and chi1.chi_version_id > chi2.chi_version_id)
        or exists (select 1 from tctg_chi_category_hierarchy chi2
                   where chi1.chi_company_id = chi2.chi_company_id
		     and chi1.chi_parent_id = chi2.chi_parent_id
                     and chi1.chi_child_id = chi2.chi_child_id
                     and chi1.chi_next_version_id = chi2.chi_next_version_id
                     and chi1.chi_version_id = chi2.chi_version_id
                     and chi1.rowid > chi2.rowid))
-- this part below is not necessary -- there to make the query run faster since
-- the below query can run off indices... dunno how useful
      and chi_parent_id in (select
                            chi_parent_id
                            from tctg_chi_category_hierarchy
                            where chi_next_version_id = 999999999
                            group by chi_parent_id, chi_child_id
                            having count(1) > 1);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Deleted [$cnt] dup chi rows!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl chi entries" 1>/dev/null 1>&2
}



#CheckDupCat
#
# some bugs with duplicate cat rows
#
CheckDupCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from tctg_cat_category cat1
    where cat1.cat_next_version_id = 999999999
    and (exists (select 1 from tctg_cat_category cat2
               where cat1.cat_company_id = cat2.cat_company_id
                 and cat1.cat_id = cat2.cat_id
                 and cat1.cat_next_version_id = cat2.cat_next_version_id
                 and cat1.cat_version_id > cat2.cat_version_id)
       or exists (select 1 from tctg_cat_category cat2
               where cat1.cat_company_id = cat2.cat_company_id
                 and cat1.cat_id = cat2.cat_id
                 and cat1.cat_next_version_id = cat2.cat_next_version_id
                 and cat1.cat_version_id = cat2.cat_version_id
                 and cat1.rowid > cat2.rowid))
-- this part below is not necessary -- there to make the query run faster since
-- the below query can run off indices... dunno how useful
    and cat1.cat_id in (select
                     cat_id
                     from tctg_cat_category
                     where cat_next_version_id = 999999999
                     group by cat_id
                     having count(1) > 1);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Deleted [$cnt] dup cat rows!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl cat entries" 1>/dev/null 1>&2
}


#CheckDupCab
#
# some bugs with duplicate cab rows
#
CheckDupCab() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from tctg_cab_category_attributes cab1
    where cab1.cab_next_version_id = 999999999
      and (exists (select 1 from tctg_cab_category_attributes cab2
                   where cab1.cab_company_id = cab2.cab_company_id
                     and cab1.cab_category_id = cab2.cab_category_id
                     and cab1.cab_node_id = cab2.cab_node_id
                     and cab1.cab_order = cab2.cab_order
                     and cab1.cab_next_version_id = cab2.cab_next_version_id
                     and cab1.cab_row_order = cab2.cab_row_order
                     and cab1.cab_version_id > cab2.cab_version_id)
           or exists (select 1 from tctg_cab_category_attributes cab2
                      where cab1.cab_company_id = cab2.cab_company_id
                        and cab1.cab_category_id = cab2.cab_category_id
                        and cab1.cab_node_id = cab2.cab_node_id
                        and cab1.cab_order = cab2.cab_order
                        and cab1.cab_next_version_id = cab2.cab_next_version_id
                        and cab1.cab_version_id = cab2.cab_version_id
                        and cab1.cab_row_order = cab2.cab_row_order
                        and cab1.rowid > cab2.rowid))
-- this part below is not necessary -- there to make the query run faster since
-- the below query can run off indices... dunno how useful
      and cab1.cab_category_id in (select
                                   cab_category_id
                                   from tctg_cab_category_attributes
                                   where cab_next_version_id = 999999999
                                   group by cab_category_id, cab_node_id, cab_order, cab_row_order
                                   having count(1) > 1);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Deleted [$cnt] dup cab rows!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl cab entries" 1>/dev/null 1>&2
}




#CheckDupItm
#
# some bugs with duplicate itm rows
#
CheckDupItm() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from tctg_itm_item itm1
    where itm1.itm_next_version_id = 999999999
      and (exists (select 1 from tctg_itm_item itm2
                   where itm1.itm_id = itm2.itm_id
                     and itm1.itm_company_id = itm2.itm_company_id
                     and itm1.itm_container_id = itm2.itm_container_id
                     and itm1.itm_next_version_id = itm2.itm_next_version_id
                     and itm1.itm_version_id > itm2.itm_version_id)
           or exists (select 1 from tctg_itm_item itm2
                      where itm1.itm_id = itm2.itm_id
                        and itm1.itm_company_id = itm2.itm_company_id
                        and itm1.itm_container_id = itm2.itm_container_id
                        and itm1.itm_next_version_id = itm2.itm_next_version_id
                        and itm1.itm_version_id = itm2.itm_version_id
                        and itm1.rowid > itm2.rowid))
-- this part below is not necessary -- there to make the query run faster since
-- the below query can run off indices... dunno how useful
      and itm1.itm_id in (select
                          itm_id
                          from tctg_itm_item
                          where itm_next_version_id = 999999999
                          group by itm_id
                          having count(1) > 1);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Deleted [$cnt] dup itm rows!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl itm entries" 1>/dev/null 1>&2
}


#CheckDupIta
#
# some bugs with duplicate ita rows
#
CheckDupIta() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from tctg_ita_item_attributes ita1
    where ita1.ita_next_version_id = 999999999
      and (exists (select 1 from tctg_ita_item_attributes ita2
                   where ita1.ita_item_id = ita2.ita_item_id
                     and ita1.ita_company_id = ita2.ita_company_id
                     and ita1.ita_catalog_id = ita2.ita_catalog_id
                     and ita1.ita_node_id = ita2.ita_node_id
                     and ita1.ita_order = ita2.ita_order
                     and ita1.ita_next_version_id = ita2.ita_next_version_id
                     and ita1.ita_row_order = ita2.ita_row_order
                     and ita1.ita_version_id > ita2.ita_version_id)
           or exists (select 1 from tctg_ita_item_attributes ita2
                      where ita1.ita_item_id = ita2.ita_item_id
                        and ita1.ita_company_id = ita2.ita_company_id
                        and ita1.ita_catalog_id = ita2.ita_catalog_id
                        and ita1.ita_node_id = ita2.ita_node_id
                        and ita1.ita_order = ita2.ita_order
                        and ita1.ita_next_version_id = ita2.ita_next_version_id
                        and ita1.ita_version_id = ita2.ita_version_id
                        and ita1.ita_row_order = ita2.ita_row_order
                        and ita1.rowid > ita2.rowid))
-- this part below is not necessary -- there to make the query run faster since
-- the below query can run off indices... dunno how useful
      and ita1.ita_item_id in (select
                               ita_item_id
                               from tctg_ita_item_attributes
                               where ita_next_version_id = 999999999
                               group by ita_item_id, ita_node_id, ita_order, ita_row_order
                               having count(1) > 1);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Deleted [$cnt] dup ita rows!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl ita entries" 1>/dev/null 1>&2
}


#CheckDupIcm
#
# some bugs with duplicate icm rows
#
CheckDupIcm() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from tctg_icm_item_category_map icm1
    where icm1.icm_next_version_id = 999999999
      and (exists (select 1 from tctg_icm_item_category_map icm2
                   where icm1.icm_item_id = icm2.icm_item_id
                     and icm1.icm_company_id = icm2.icm_company_id
                     and icm1.icm_catalog_id = icm2.icm_catalog_id
                     and icm1.icm_cat_tree_id = icm2.icm_cat_tree_id
                     and icm1.icm_category_id = icm2.icm_category_id
                     and icm1.icm_next_version_id = icm2.icm_next_version_id
                     and icm1.icm_version_id > icm2.icm_version_id)
           or exists (select 1 from tctg_icm_item_category_map icm2
                      where icm1.icm_item_id = icm2.icm_item_id
                        and icm1.icm_company_id = icm2.icm_company_id
                        and icm1.icm_catalog_id = icm2.icm_catalog_id
                        and icm1.icm_cat_tree_id = icm2.icm_cat_tree_id
                        and icm1.icm_category_id = icm2.icm_category_id
                        and icm1.icm_next_version_id = icm2.icm_next_version_id
                        and icm1.icm_version_id = icm2.icm_version_id
                        and icm1.rowid > icm2.rowid))
-- this part below is not necessary -- there to make the query run faster since
-- the below query can run off indices... dunno how useful
      and icm1.icm_item_id in (select
                               icm_item_id
                               from tctg_icm_item_category_map
                               where icm_next_version_id = 999999999
                               group by icm_cat_tree_id, icm_item_id, icm_category_id
                               having count(1) > 1);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Deleted [$cnt] dup icm rows!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl icm entries" 1>/dev/null 1>&2
}


#CheckDeadIta
#
# dead ita that refer to non existing items
#
CheckDeadIta() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile
    delete from tctg_ita_item_attributes where ita_next_version_id = 999999999 and not exists (select itm_id from tctg_itm_item where itm_id = ita_item_id and itm_next_version_id = 999999999);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Removed [$cnt] invalid ita entries";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for ita rows refering to non existing items" 1>/dev/null 1>&2
}


#CheckDeadIcm
#
# dead icm that refer to non existing items
#
CheckDeadIcm() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile
    delete from tctg_icm_item_category_map where icm_next_version_id = 999999999 and not exists (select itm_id from tctg_itm_item where itm_id = icm_item_id and itm_next_version_id = 999999999);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Removed [$cnt] invalid icm entries";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for icm rows refering to non existing items" 1>/dev/null 1>&2
}


#CheckDeadItm
#
# dead itm that refer to non existing icm
# need to do per ctr
# LKP TABLES ARE EXCLUDED because of no migration!!!
#
CheckDeadItm() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    set serveroutput on size 1000000;
    $TOP_SQL
    spool $tmpfile;
declare
count_errs number;
ctg_name varchar2(3000);
ctg_id number;
ctg_company_id number;
ctr_id number;
ctr_name varchar2(3000);

cursor ctg_row is
       select * from tctg_ctg_catalog where ctg_type = 'CATALOG';

cursor caa_row(ctg_id number) is
       select * from tctg_caa_catalog_attributes, tctg_ctr_category_tree where caa_catalog_id = ctg_id and caa_name = 'CATEGORY_TREE_ID' and caa_next_version_id = 999999999 and ctr_id = caa_value;

BEGIN
for ctg_record in ctg_row loop
    ctg_name := ctg_record.ctg_name;
    ctg_id := ctg_record.ctg_id;
    ctg_company_id := ctg_record.ctg_company_id;
    for caa_record in caa_row(ctg_id) loop
        ctr_id := caa_record.ctr_id;
        ctr_name := caa_record.ctr_name;

        --now do count of itm/icm to see if there are any missing rows
        select
        count(1) into count_errs
        from tctg_itm_item
        where itm_next_version_id = 999999999
          and itm_container_id = ctg_id  -- ctg_id from what we select earlier
        and not exists (select
                        1
                        from tctg_icm_item_category_map
                        where icm_item_id = itm_id
                          and icm_catalog_id = ctg_id  --ctg_id from where we select earlier
                          and icm_cat_tree_id = ctr_id --ctr_id from what we selected earlier
                          and icm_next_version_id = 999999999);
                  
                                 
       if (count_errs > 0) then
       delete from tctg_itm_item
		        where itm_next_version_id = 999999999
		          and itm_container_id = ctg_id  -- ctg_id from what we select earlier
		        and not exists (select
		                        1
		                        from tctg_icm_item_category_map
		                        where icm_item_id = itm_id
		                          and icm_catalog_id = ctg_id  --ctg_id from where we select earlier
		                          and icm_cat_tree_id = ctr_id --ctr_id from what we selected earlier
                          and icm_next_version_id = 999999999);
        commit;
        dbms_output.put_line(count_errs || ' itms with no icms found and deleted for ctg_id = [' || ctg_id || '] ctg_name = [' || ctg_name || '] ctr_id = [' || ctr_id || '] ctr_name = [' || ctr_name || ']  !!!!!');
       end if;
    end loop;
end loop;
end;
/
    spool off;
EOF
    txt=`cat $tmpfile | grep -v 'SQL'`
    if [ "$txt" != "" ]; then
        ${ECHO} "$txt";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with check and delete of itm rows refering to non existing icms" 1>/dev/null 1>&2
}

#CheckCsmCat
#
# ROWS IN CSM NOT IN CAT
#

CheckCsmCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from csm where csm_category_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
        and cfp_next_version_id=999999999);
    commit; 
    spool off;
    
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows deleted." ]; then
     ${ECHO} "Removed [$cnt] invalid CSM entries not in CAT";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for CSMs not in CAT" 1>/dev/null 1>&2
}


#CheckCsaCat
#
# ROWS IN CSA NOT IN CAT
#

CheckCsaCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from csa where csa_category_id in 
            (select cfp_category_id 
            from cfp 
            where cfp_category_id  not in 
                (select distinct cat_id 
                from cat 
                where cat_next_version_id = 999999999) 
        and cfp_next_version_id=999999999);
     commit;
     spool off;
             
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
       if [ "$cnt" != "0 rows deleted." ]; then
         ${ECHO} "Removed [$cnt] invalid CSA entries not in CAT";
       fi
       ${RM} $tmpfile
       ${ECHO} "done with test for CSAs not in CAT" 1>/dev/null 1>&2
}


#CheckChiParentCat
#
# PARENT ROWS IN CHI NOT IN CAT
#

CheckChiParentCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from chi where chi_parent_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
            and cfp_next_version_id=999999999);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
         if [ "$cnt" != "0 rows deleted." ]; then
           ${ECHO} "Removed [$cnt] invalid parent CHI entries not in CAT";
         fi
         ${RM} $tmpfile
         ${ECHO} "done with test for parent CHIs not in CAT" 1>/dev/null 1>&2
}


#CheckChiChildCat
#
# CHILD ROWS IN CHI NOT IN CAT

CheckChiChildCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from chi where chi_child_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
        and cfp_next_version_id=999999999);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
       if [ "$cnt" != "0 rows deleted." ]; then
         ${ECHO} "Removed [$cnt] invalid child CHI entries not in CAT";
       fi
       ${RM} $tmpfile
       ${ECHO} "done with test for child CHIs not in CAT" 1>/dev/null 1>&2
}


#CheckCcmSourceCat
#
# SOURCE ROWS IN CCM NOT IN CAT
#

CheckCcmSourceCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from ccm where ccm_src_category_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
            and cfp_next_version_id=999999999);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
      if [ "$cnt" != "0 rows deleted." ]; then
       ${ECHO} "Removed [$cnt] invalid source CCM entries not in CAT";
      fi
      ${RM} $tmpfile
      ${ECHO} "done with test for source CCMs not in CAT" 1>/dev/null 1>&2
}


#CheckCcmDestCat
#
# DESTINATION ROWS IN CCM NOT IN CAT
#

CheckCcmDestCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from ccm where ccm_dst_category_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
        and cfp_next_version_id=999999999);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
      if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Removed [$cnt] invalid dest CCM entries not in CAT";
      fi
      ${RM} $tmpfile
      ${ECHO} "done with test for dest CCMs not in CAT" 1>/dev/null 1>&2
}


#CheckIcmCat
#
# ROWS IN ICM NOT IN CAT

CheckIcmCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from icm where icm_category_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
            and cfp_next_version_id=999999999);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
      if [ "$cnt" != "0 rows deleted." ]; then
         ${ECHO} "Removed [$cnt] invalid ICM entries not in CAT";
      fi
      ${RM} $tmpfile
      ${ECHO} "done with test for ICMs not in CAT" 1>/dev/null 1>&2
    }

#CheckCfpCat
#
# ROWS IN CFP NOT IN CAT 

CheckCfpCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from cfp where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
    and cfp_next_version_id=999999999;
    commit;
    spool off;
    
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
        if [ "$cnt" != "0 rows deleted." ]; then
            ${ECHO} "Removed [$cnt] invalid CFP entries not in CAT";
        fi
        ${RM} $tmpfile
        ${ECHO} "done with test for CFPs not in CAT" 1>/dev/null 1>&2
}


#CheckCsmCfp
#
# ROWS IN CSM NOT IN CFP
# 

CheckCsmCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from csm where csm_category_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
        and cat_next_version_id=999999999);
    commit;
    spool off;

EOF

cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
   if [ "$cnt" != "0 rows deleted." ]; then
   ${ECHO} "Removed [$cnt] invalid CSM entries not in CFP";
   fi
   ${RM} $tmpfile
   ${ECHO} "done with test for CSMs not in CFP" 1>/dev/null 1>&2
}



#CheckCsaCfp
#
# ROWS IN CSA NOT IN CFP
# 

CheckCsaCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from csa where csa_category_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
        and cat_next_version_id=999999999);
    commit;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
       if [ "$cnt" != "0 rows deleted." ]; then
       ${ECHO} "Removed [$cnt] invalid CSA entries not in CFP";
       fi
       ${RM} $tmpfile
       ${ECHO} "done with test for CSAs not in CFP" 1>/dev/null 1>&2
}


#CheckChiParentCfp
#
# PARENT ROWS IN CHI NOT IN CFP
# 

CheckChiParentCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from chi where chi_parent_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
            and cat_next_version_id=999999999);
    commit;
    spool off;

EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
       if [ "$cnt" != "0 rows deleted." ]; then
       ${ECHO} "Removed [$cnt] invalid parent CHI entries not in CFP";
       fi
       ${RM} $tmpfile
       ${ECHO} "done with test for parent CHIs not in CFP" 1>/dev/null 1>&2
}


#CheckChiChildCfp
#
# CHILD ROWS IN CHI NOT IN CFP
# 

CheckChiChildCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from chi where chi_child_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
        and cat_next_version_id=999999999);
    commit;
    spool off;

EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
           if [ "$cnt" != "0 rows deleted." ]; then
           ${ECHO} "Removed [$cnt] invalid child CHI entries not in CFP";
           fi
           ${RM} $tmpfile
           ${ECHO} "done with test for child CHIs not in CFP" 1>/dev/null 1>&2
    }



#CheckCcmSourceCfp
#
# SRC ROWS IN CCM NOT IN CFP
# 

CheckCcmSourceCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from ccm where ccm_src_category_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
            and cat_next_version_id=999999999);
    commit;
    spool off;

EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
    if [ "$cnt" != "0 rows deleted." ]; then
    ${ECHO} "Removed [$cnt] invalid source CCM entries not in CFP";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for source CCMs not in CFP" 1>/dev/null 1>&2
 }
        



#CheckCcmDestCfp
#
# DEST ROWS IN CCM NOT IN CFP
# 

CheckCcmDestCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from ccm where ccm_dst_category_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
        and cat_next_version_id=999999999);
    commit;
spool off;

EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
        if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Removed [$cnt] invalid dest CCM entries not in CFP";
        fi
        ${RM} $tmpfile
        ${ECHO} "done with test for dest CCMs not in CFP" 1>/dev/null 1>&2
 }


#CheckIcmCfp
#
# ROWS IN ICM NOT IN CFP
# 

CheckIcmCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from icm where icm_category_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
            and cat_next_version_id=999999999);
    commit;
    spool off;
    
EOF
cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
        if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Removed [$cnt] invalid ICM entries not in CFP";
        fi
        ${RM} $tmpfile
        ${ECHO} "done with test for ICMs not in CFP" 1>/dev/null 1>&2
 }
 

#CheckCatCfp
#
# ROWS IN CAT NOT IN CFP
# 

CheckCatCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    delete from cat
    where cat_id  not in 
        (select distinct cfp_category_id 
        from cfp 
        where cfp_next_version_id = 999999999) 
    and cat_next_version_id=999999999;
    commit;
    spool off;
EOF
cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL' | ${GREP} -v "Commit complete" | ${GREP} -v "^$"`
        if [ "$cnt" != "0 rows deleted." ]; then
        ${ECHO} "Removed [$cnt] invalid CAT entries not in CFP";
        fi
        ${RM} $tmpfile
        ${ECHO} "done with test for CATs not in CFP" 1>/dev/null 1>&2
 }
 
#CheckCat
#
# Check to see if Category tables exist
#

CheckCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    set feedback off;
    spool $tmpfile;
    select
    count(1) from user_tables where table_name = 'TCTG_CFP_CAT_FULL_PATHS';

spool off;

EOF
cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
if [ "$cnt" != "0" ]; then
CheckCsmCat
CheckCsaCat
CheckChiParentCat
CheckChiChildCat
CheckCcmSourceCat
CheckCcmDestCat
CheckIcmCat
CheckCfpCat
CheckCsmCfp
CheckCsaCfp
CheckChiParentCfp
CheckChiChildCfp
CheckCcmSourceCfp
CheckCcmDestCfp
CheckIcmCfp
CheckCatCfp
fi
    ${RM} $tmpfile
}

#
# Main
#

CheckItaValueNumeric
CheckDupChi
CheckDupCat
CheckDupCab
CheckDupItm
CheckDupIta
CheckDupIcm
CheckDeadIta
CheckDeadIcm
CheckDeadItm
CheckCat

